

clear all
use data.dta

***基准回归
reghdfe ls treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id year) vce(cluster id)
reghdfe ls treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id ind#year) vce(cluster id)
reghdfe lnls treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id year) vce(cluster id)
reghdfe lnls treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id ind#year) vce(cluster id)

***平行趋势检验
gen event = year - policyyear
sum event
replace event=-5 if event<-5
forvalues i=5(-1)1{
  gen before`i'=(event==-`i'& treat==1)
}
gen current=(event==0 & treat==1)
forvalues i=1(1)3{
  gen after`i'=(event==`i'& treat==1)
}
reghdfe ls before5 before4 before3 before2 current after* lnsize roa lnage  cfo top10 boardsize manaexp lev,absorb(id ind#year) cluster(id)
coefplot, baselevels  keep(before* current after*) vertical levels(95) yline(0,lcolor(edkblue*0.8)) xline(5, lwidth(vthin) lpattern(dash) lcolor(teal)) ylabel(,labsize(*0.75)) xlabel(,labsize(*0.75)) ytitle("系数", size(small)) xtitle("政策时点", size(small)) addplot(line @b @at) ciopts(lpattern(dash) recast(rcap) msize(medium)) msymbol(circle_hollow) scheme(s1mono) omitted coeflabels(before5="-5"  before4="-4" before3="-3" before2="-2"  current="0" after1="1" after2="2" after3="3" ) 

***稳健性检验
* 异质性处理效应
gen first_treat=0
replace first_treat=policyyear if policyyear~=.
csdid ls lnsize roa lev lnage cfo top10 boardsize manaexp,ivar(id) time(year) gvar(first_treat) method(dripw) agg(simple) notyet 

* 考虑试点的非随机性
gen coastal=沿海
gen lnpgdp2007=ln(pgdp2007)
gen t=year-2006
gen tt=t*t
gen tcoastal=沿海*t
gen tlnpgdp2007=lnpgdp2007*t
gen tfiscal2007=fiscal2007*t
gen tindustry2007=industry2007*t
gen turban2007=urban2007*t
gen ttcoastal=沿海*tt
gen ttlnpgdp2007=lnpgdp2007*tt
gen ttfiscal2007=fiscal2007*tt
gen ttindustry2007=industry2007*tt
gen tturban2007=urban2007*tt
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev tlnpgdp2007 tfiscal2007 tindustry2007 turban2007 tturban2007 ttlnpgdp2007 ttfiscal2007 ttindustry2007 tcoastal ttcoastal,absorb(id ind#year) vce(cluster id)

* PSM-DID
forvalues i=2007(1)2019 {
qui use 平行趋势检验.dta
qui keep if year==`i'
qui set seed 0001 //定义种子
qui gen tmp = runiform() //生成随机数
qui sort tmp //把数据库随机整理
qui psmatch2 treat lnsize roa lnage cfo top10 boardsize manaexp lev, logit out(ls) common cal(0.001) n(1)
qui gen common=_support
qui drop if common == 0  //去掉不满足共同区域假定的观测值
pstest lnsize roa lnage  cfo top10 boardsize manaexp  lev  // 查看处理组与控制组随机化的效果
qui save psm`i',replace
}
use psm2007,clear
save psm,replace
forvalues i=2008(1)2019 {
use psm,clear
append using psm`i'
save psm,replace
}
use psm,clear
reghdfe ls treat_post  lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)

* 替换被解释变量
reghdfe ls1 treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id ind#year) vce(cluster id)
reghdfe ls2 treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id ind#year) vce(cluster id)
reghdfe ls3 treat_post lnsize roa lev lnage cfo top10 boardsize manaexp,absorb(id ind#year) vce(cluster id)

* 排除政策干扰
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev gpjz ftz,absorb(id ind#year) vce(cluster id)

* 安慰剂检验
permute treat_post beta=_b[treat_post] se = _se[treat_post] df = e(df_r),reps(1000) saving("permute.dta"):reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)
use permute.dta,replace
gen t_value = beta / se
gen p_value = 2 * ttail(df, abs(beta/se))
dpplot beta, xline(0.0031,lc(black*0.5) lp(dash))xtitle("估计系数", size(*0.8)) xlabel(,labsize(small)) ytitle("核密度", size(*0.8)) ylabel(, labsize(small)) note("") caption("") graphregion(fcolor(white)) 

***一般均衡效应分析
bys prov year:egen medianls_prov=median(ls)
bys prov year:egen sumls_prov=sum(ls)
bys prov year:egen lnsize_prov=mean(lnsize)
bys prov year:egen roa_prov=mean(roa)
bys prov year:egen lnage_prov=mean(lnage)
bys prov year:egen cfo_prov=mean(cfo)
bys prov year:egen top10_prov=mean(top10)
bys prov year:egen boardsize_prov=mean(boardsize)
bys prov year:egen manaexp_prov=mean(manaexp)
bys prov year:egen lev_prov=mean(lev)
duplicates drop sumls_prov lnsize_prov roa_prov lnage_prov cfo_prov top10_prov boardsize_prov manaexp_prov lev_prov,force
reghdfe sumls_prov treat_post lnsize_prov roa_prov lnage_prov cfo_prov top10_prov boardsize_prov manaexp_prov lev_prov,absorb(prov year) vce(r)
reghdfe medianls5_prov treat_post lnsize_prov roa_prov lnage_prov cfo_prov top10_prov boardsize_prov manaexp_prov lev_prov,absorb(prov year) vce(r)


***机制检验
use 企业进入data.dta,replace
reghdfe oi treat_post lnpgdp indust_struc lnpopu tec  road human, absorb(id year) vce(r)
reghdfe entre_popu treat_post lnpgdp indust_struc lnpopu tec  road human, absorb(id year) vce(r)

use data.dta replace
drop if 权益资本<=0
winsor2 pmc,cut(1 99) replace
bys ind year:egen meant=mean(pmc)
gen adjpmc=pmc-meant
reghdfe ls c.adjpmc##treat_post lnsize roa lnage cfo top10 boardsize manaexp  lev,absorb(id ind#year) vce(cluster id)

reghdfe ls c.invest##treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)  
reghdfe ls c.absin##treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if 残差>0,absorb(id ind#year ) vce(cluster id)

reghdfe ls c.rd##treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)  


***扩展性分析
* 提升员工待遇
gen high_skill=(本科生人数占比+硕士人数占比+博士人数占比)/100
gen high_edu1=(销售人员人数占比+财务人员人数占比+技术人员人数占比)/100
reghdfe ls c.high_skill##treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)
reghdfe ls c.high_edu##treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)

* 共同富裕
gen mls=高管薪酬总额/(营业总收入-营业成本+应付职工薪酬+固定资产折旧油气资产折耗生产性生物资产折旧)
gen lls=(应付职工薪酬-高管薪酬总额)/(营业总收入-营业成本+应付职工薪酬+固定资产折旧油气资产折耗生产性生物资产折旧)
gen gap=ln((高管薪酬总额/高管人数)/(应付职工薪酬/员工人数))
winsor2 lls mls fpg,cut(1 99) replace
reghdfe mls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)
reghdfe lls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)
reghdfe gap treat_post lnsize roa lnage cfo top10 boardsize manaexp lev,absorb(id ind#year) vce(cluster id)

* 异质性分析
bys year:egen market=median(政府与市场关系)
gen marketgroup=(政府与市场关系>=market)
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if marketgroup==1,absorb(id ind#year) vce(cluster id)
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if marketgroup==0,absorb(id ind#year) vce(cluster id)

gen industry=(大类行业代码=="B"|大类行业代码=="C"|大类行业代码=="D")
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if industry==1,absorb(id ind#year) vce(cluster id)
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if industry==0,absorb(id ind#year) vce(cluster id) 

reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if soe==1,absorb(id ind#year) vce(cluster id)
reghdfe ls treat_post lnsize roa lnage cfo top10 boardsize manaexp lev if soe==0,absorb(id ind#year) vce(cluster id)


















